=============================================
Microsoft.Recognizers.Text.Suite for Python
=============================================

Please check the `main README`_ for more details.

.. _main README: https://github.com/Microsoft/Recognizers-Text/tree/master/Python